import React, { useEffect, useState } from 'react'
import axios from 'axios'
import { Link } from 'react-router-dom'
import { API_BASE_URL } from '../config'


const TagSidebar: React.FC = () => {
  const [tags, setTags] = useState<Array<{ id: number, name: string }>>([])

  useEffect(() => {
    const fetchTags = async () => {
      try {
        const response = await axios.get (`${API_BASE_URL}/tags`)
        setTags(response.data)
      } catch (error) {
        console.error('Failed to fetch tags:', error)
      }
    }

    fetchTags()
  }, [])

  return (
    <div className="w-64 bg-gray-100 p-4 border-r border-gray-200 h-full">
      <h2 className="text-xl font-bold mb-4">タグ一覧</h2>
      <ul>
        {tags.map (tag => (
          <li key={tag.id} className="mb-2">
            <Link to={`/tags/${tag.id}`} className="text-blue-600 hover:underline">
              {tag.name}
            </Link>
          </li>
        ))}
      </ul>
    </div>
  )
}

export default TagSidebar
